# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


__all__ = ['NUAddressMapsFetcher', 'NUAddressRangesFetcher', 'NUAggregateMetadatasFetcher', 'NUAlarmsFetcher', 'NUAllAlarmsFetcher', 'NUAllGatewaysFetcher', 'NUAllRedundancyGroupsFetcher', 'NUApplicationBindingsFetcher', 'NUApplicationperformancemanagementbindingsFetcher', 'NUApplicationperformancemanagementsFetcher', 'NUApplicationsFetcher', 'NUAutoDiscoverClustersFetcher', 'NUAutodiscovereddatacentersFetcher', 'NUAutoDiscoveredGatewaysFetcher', 'NUAutoDiscoverHypervisorFromClustersFetcher', 'NUAvatarsFetcher', 'NUBFDSessionsFetcher', 'NUBGPNeighborsFetcher', 'NUBGPPeersFetcher', 'NUBGPProfilesFetcher', 'NUBootstrapActivationsFetcher', 'NUBootstrapsFetcher', 'NUBRConnectionsFetcher', 'NUBridgeInterfacesFetcher', 'NUBulkStatisticsFetcher', 'NUCaptivePortalProfilesFetcher', 'NUCertificatesFetcher', 'NUCloudMgmtSystemsFetcher', 'NUCommandsFetcher', 'NUConnectionendpointsFetcher', 'NUContainerInterfacesFetcher', 'NUContainerResyncsFetcher', 'NUContainersFetcher', 'NUCOSRemarkingPoliciesFetcher', 'NUCOSRemarkingPolicyTablesFetcher', 'NUCSNATPoolsFetcher', 'NUCTranslationMapsFetcher', 'NUCustomPropertiesFetcher', 'NUDefaultGatewaysFetcher', 'NUDemarcationServicesFetcher', 'NUDeploymentFailuresFetcher', 'NUDestinationurlsFetcher', 'NUDHCPOptionsFetcher', 'NUDiskStatsFetcher', 'NUDomainFIPAclTemplateEntriesFetcher', 'NUDomainFIPAclTemplatesFetcher', 'NUDomainsFetcher', 'NUDomainTemplatesFetcher', 'NUDownloadProgressFetcher', 'NUDSCPForwardingClassMappingsFetcher', 'NUDSCPForwardingClassTablesFetcher', 'NUDSCPRemarkingPoliciesFetcher', 'NUDSCPRemarkingPolicyTablesFetcher', 'NUDUCGroupBindingsFetcher', 'NUDUCGroupsFetcher', 'NUEgressACLEntryTemplatesFetcher', 'NUEgressACLTemplatesFetcher', 'NUEgressAdvFwdEntryTemplatesFetcher', 'NUEgressAdvFwdTemplatesFetcher', 'NUEgressProfilesFetcher', 'NUEgressQOSPoliciesFetcher', 'NUEnterpriseNetworksFetcher', 'NUEnterprisePermissionsFetcher', 'NUEnterpriseProfilesFetcher', 'NUEnterprisesFetcher', 'NUEnterpriseSecuredDatasFetcher', 'NUEnterpriseSecuritiesFetcher', 'NUEventLogsFetcher', 'NUFirewallAclsFetcher', 'NUFirewallRulesFetcher', 'NUFloatingIpsFetcher', 'NUForwardingPathListEntriesFetcher', 'NUForwardingPathListsFetcher', 'NUGatewayRedundantPortsFetcher', 'NUGatewaysFetcher', 'NUGatewaySecuredDatasFetcher', 'NUGatewaySecuritiesFetcher', 'NUGatewaysLocationsFetcher', 'NUGatewayTemplatesFetcher', 'NUGlobalMetadatasFetcher', 'NUGroupKeyEncryptionProfilesFetcher', 'NUGroupsFetcher', 'NUHostInterfacesFetcher', 'NUHSCsFetcher', 'NUIKECertificatesFetcher', 'NUIKEEncryptionprofilesFetcher', 'NUIKEGatewayConfigsFetcher', 'NUIKEGatewayConnectionsFetcher', 'NUIKEGatewayProfilesFetcher', 'NUIKEGatewaysFetcher', 'NUIKEPSKsFetcher', 'NUIKESubnetsFetcher', 'NUInfrastructureAccessProfilesFetcher', 'NUInfrastructureConfigsFetcher', 'NUInfrastructureEVDFProfilesFetcher', 'NUInfrastructureGatewayProfilesFetcher', 'NUInfrastructureVscProfilesFetcher', 'NUIngressACLEntryTemplatesFetcher', 'NUIngressACLTemplatesFetcher', 'NUIngressAdvFwdEntryTemplatesFetcher', 'NUIngressAdvFwdTemplatesFetcher', 'NUIngressProfilesFetcher', 'NUIngressQOSPoliciesFetcher', 'NUIPFilterProfilesFetcher', 'NUIPReservationsFetcher', 'NUIPv6FilterProfilesFetcher', 'NUJobsFetcher', 'NUKeyServerMembersFetcher', 'NUKeyServerMonitorEncryptedSeedsFetcher', 'NUKeyServerMonitorsFetcher', 'NUKeyServerMonitorSeedsFetcher', 'NUKeyServerMonitorSEKsFetcher', 'NUL2DomainsFetcher', 'NUL2DomainTemplatesFetcher', 'NUL4ServiceGroupsFetcher', 'NUL4ServicesFetcher', 'NUL7applicationsignaturesFetcher', 'NULDAPConfigurationsFetcher', 'NULicensesFetcher', 'NULicenseStatusFetcher', 'NULinksFetcher', 'NULocationsFetcher', 'NULTEInformationsFetcher', 'NULtestatisticsFetcher', 'NUMACFilterProfilesFetcher', 'NUMesFetcher', 'NUMetadatasFetcher', 'NUMirrorDestinationsFetcher', 'NUMonitoringPortsFetcher', 'NUMonitorscopesFetcher', 'NUMultiCastChannelMapsFetcher', 'NUMultiCastListsFetcher', 'NUMultiCastRangesFetcher', 'NUMultiNICVPortsFetcher', 'NUNATMapEntriesFetcher', 'NUNetconfManagersFetcher', 'NUNetconfProfilesFetcher', 'NUNetconfSessionsFetcher', 'NUNetworkLayoutsFetcher', 'NUNetworkMacroGroupsFetcher', 'NUNetworkPerformanceBindingsFetcher', 'NUNetworkPerformanceMeasurementsFetcher', 'NUNextHopsFetcher', 'NUNSGatewayMonitorsFetcher', 'NUNSGatewaysFetcher', 'NUNSGatewaysCountsFetcher', 'NUNSGatewaySummariesFetcher', 'NUNSGatewayTemplatesFetcher', 'NUNSGGroupsFetcher', 'NUNSGInfosFetcher', 'NUNSGPatchProfilesFetcher', 'NUNSGRoutingPolicyBindingsFetcher', 'NUNSGUpgradeProfilesFetcher', 'NUNSPortInfosFetcher', 'NUNSPortsFetcher', 'NUNSPortTemplatesFetcher', 'NUNSRedundantGatewayGroupsFetcher', 'NUOSPFAreasFetcher', 'NUOSPFInstancesFetcher', 'NUOSPFInterfacesFetcher', 'NUOverlayAddressPoolsFetcher', 'NUOverlayManagementProfilesFetcher', 'NUOverlayManagementSubnetProfilesFetcher', 'NUOverlayMirrorDestinationsFetcher', 'NUOverlayMirrorDestinationTemplatesFetcher', 'NUOverlayPATNATEntriesFetcher', 'NUPatchsFetcher', 'NUPATIPEntriesFetcher', 'NUPATMappersFetcher', 'NUPATNATPoolsFetcher', 'NUPerformanceMonitorsFetcher', 'NUPermissionsFetcher', 'NUPGExpressionsFetcher', 'NUPGExpressionTemplatesFetcher', 'NUPolicyDecisionsFetcher', 'NUPolicyEntriesFetcher', 'NUPolicyGroupCategoriesFetcher', 'NUPolicyGroupsFetcher', 'NUPolicyGroupTemplatesFetcher', 'NUPolicyObjectGroupsFetcher', 'NUPolicyStatementsFetcher', 'NUPortMappingsFetcher', 'NUPortsFetcher', 'NUPortTemplatesFetcher', 'NUProxyARPFiltersFetcher', 'NUPSNATPoolsFetcher', 'NUPSPATMapsFetcher', 'NUPTranslationMapsFetcher', 'NUPublicNetworkMacrosFetcher', 'NUQosPolicersFetcher', 'NUQOSsFetcher', 'NURateLimitersFetcher', 'NURedirectionTargetsFetcher', 'NURedirectionTargetTemplatesFetcher', 'NURedundancyGroupsFetcher', 'NURedundantPortsFetcher', 'NURoutingPoliciesFetcher', 'NUSaaSApplicationGroupsFetcher', 'NUSaaSApplicationTypesFetcher', 'NUSAPEgressQoSProfilesFetcher', 'NUSAPIngressQoSProfilesFetcher', 'NUSharedNetworkResourcesFetcher', 'NUShuntLinksFetcher', 'NUSiteInfosFetcher', 'NUSPATSourcesPoolsFetcher', 'NUSSHKeysFetcher', 'NUSSIDConnectionsFetcher', 'NUStaticRoutesFetcher', 'NUStatisticsFetcher', 'NUStatisticsPoliciesFetcher', 'NUStatsCollectorInfosFetcher', 'NUSubnetsFetcher', 'NUSubnetTemplatesFetcher', 'NUSyslogDestinationsFetcher', 'NUSystemConfigsFetcher', 'NUTCAsFetcher', 'NUTiersFetcher', 'NUTrunksFetcher', 'NUUnderlaysFetcher', 'NUUplinkConnectionsFetcher', 'NUUplinkRDsFetcher', 'NUUserContextsFetcher', 'NUUsersFetcher', 'NUVCenterClustersFetcher', 'NUVCenterDataCentersFetcher', 'NUVCenterEAMConfigsFetcher', 'NUVCenterHypervisorsFetcher', 'NUVCentersFetcher', 'NUVCenterVRSConfigsFetcher', 'NUVirtualFirewallPoliciesFetcher', 'NUVirtualFirewallRulesFetcher', 'NUVirtualIPsFetcher', 'NUVLANsFetcher', 'NUVLANTemplatesFetcher', 'NUVMInterfacesFetcher', 'NUVMResyncsFetcher', 'NUVMsFetcher', 'NUVNFCatalogsFetcher', 'NUVNFDescriptorsFetcher', 'NUVNFDomainMappingsFetcher', 'NUVNFInterfaceDescriptorsFetcher', 'NUVNFInterfacesFetcher', 'NUVNFMetadatasFetcher', 'NUVNFsFetcher', 'NUVNFThresholdPoliciesFetcher', 'NUVPNConnectionsFetcher', 'NUVPortMirrorsFetcher', 'NUVPortsFetcher', 'NUVRSAddressRangesFetcher', 'NUVRSMetricsFetcher', 'NUVRSRedeploymentpoliciesFetcher', 'NUVRSsFetcher', 'NUVSCsFetcher', 'NUVSDComponentsFetcher', 'NUVSDsFetcher', 'NUVsgRedundantPortsFetcher', 'NUVSPsFetcher', 'NUWANServicesFetcher', 'NUWebCategoriesFetcher', 'NUWebDomainNamesFetcher', 'NUWirelessPortsFetcher', 'NUZFBAutoAssignmentsFetcher', 'NUZFBRequestsFetcher', 'NUZonesFetcher', 'NUZoneTemplatesFetcher']

from .nuaddressmaps_fetcher import NUAddressMapsFetcher
from .nuaddressranges_fetcher import NUAddressRangesFetcher
from .nuaggregatemetadatas_fetcher import NUAggregateMetadatasFetcher
from .nualarms_fetcher import NUAlarmsFetcher
from .nuallalarms_fetcher import NUAllAlarmsFetcher
from .nuallgateways_fetcher import NUAllGatewaysFetcher
from .nuallredundancygroups_fetcher import NUAllRedundancyGroupsFetcher
from .nuapplicationbindings_fetcher import NUApplicationBindingsFetcher
from .nuapplicationperformancemanagementbindings_fetcher import NUApplicationperformancemanagementbindingsFetcher
from .nuapplicationperformancemanagements_fetcher import NUApplicationperformancemanagementsFetcher
from .nuapplications_fetcher import NUApplicationsFetcher
from .nuautodiscoverclusters_fetcher import NUAutoDiscoverClustersFetcher
from .nuautodiscovereddatacenters_fetcher import NUAutodiscovereddatacentersFetcher
from .nuautodiscoveredgateways_fetcher import NUAutoDiscoveredGatewaysFetcher
from .nuautodiscoverhypervisorfromclusters_fetcher import NUAutoDiscoverHypervisorFromClustersFetcher
from .nuavatars_fetcher import NUAvatarsFetcher
from .nubfdsessions_fetcher import NUBFDSessionsFetcher
from .nubgpneighbors_fetcher import NUBGPNeighborsFetcher
from .nubgppeers_fetcher import NUBGPPeersFetcher
from .nubgpprofiles_fetcher import NUBGPProfilesFetcher
from .nubootstrapactivations_fetcher import NUBootstrapActivationsFetcher
from .nubootstraps_fetcher import NUBootstrapsFetcher
from .nubrconnections_fetcher import NUBRConnectionsFetcher
from .nubridgeinterfaces_fetcher import NUBridgeInterfacesFetcher
from .nubulkstatistics_fetcher import NUBulkStatisticsFetcher
from .nucaptiveportalprofiles_fetcher import NUCaptivePortalProfilesFetcher
from .nucertificates_fetcher import NUCertificatesFetcher
from .nucloudmgmtsystems_fetcher import NUCloudMgmtSystemsFetcher
from .nucommands_fetcher import NUCommandsFetcher
from .nuconnectionendpoints_fetcher import NUConnectionendpointsFetcher
from .nucontainerinterfaces_fetcher import NUContainerInterfacesFetcher
from .nucontainerresyncs_fetcher import NUContainerResyncsFetcher
from .nucontainers_fetcher import NUContainersFetcher
from .nucosremarkingpolicies_fetcher import NUCOSRemarkingPoliciesFetcher
from .nucosremarkingpolicytables_fetcher import NUCOSRemarkingPolicyTablesFetcher
from .nucsnatpools_fetcher import NUCSNATPoolsFetcher
from .nuctranslationmaps_fetcher import NUCTranslationMapsFetcher
from .nucustomproperties_fetcher import NUCustomPropertiesFetcher
from .nudefaultgateways_fetcher import NUDefaultGatewaysFetcher
from .nudemarcationservices_fetcher import NUDemarcationServicesFetcher
from .nudeploymentfailures_fetcher import NUDeploymentFailuresFetcher
from .nudestinationurls_fetcher import NUDestinationurlsFetcher
from .nudhcpoptions_fetcher import NUDHCPOptionsFetcher
from .nudiskstats_fetcher import NUDiskStatsFetcher
from .nudomainfipacltemplateentries_fetcher import NUDomainFIPAclTemplateEntriesFetcher
from .nudomainfipacltemplates_fetcher import NUDomainFIPAclTemplatesFetcher
from .nudomains_fetcher import NUDomainsFetcher
from .nudomaintemplates_fetcher import NUDomainTemplatesFetcher
from .nudownloadprogress_fetcher import NUDownloadProgressFetcher
from .nudscpforwardingclassmappings_fetcher import NUDSCPForwardingClassMappingsFetcher
from .nudscpforwardingclasstables_fetcher import NUDSCPForwardingClassTablesFetcher
from .nudscpremarkingpolicies_fetcher import NUDSCPRemarkingPoliciesFetcher
from .nudscpremarkingpolicytables_fetcher import NUDSCPRemarkingPolicyTablesFetcher
from .nuducgroupbindings_fetcher import NUDUCGroupBindingsFetcher
from .nuducgroups_fetcher import NUDUCGroupsFetcher
from .nuegressaclentrytemplates_fetcher import NUEgressACLEntryTemplatesFetcher
from .nuegressacltemplates_fetcher import NUEgressACLTemplatesFetcher
from .nuegressadvfwdentrytemplates_fetcher import NUEgressAdvFwdEntryTemplatesFetcher
from .nuegressadvfwdtemplates_fetcher import NUEgressAdvFwdTemplatesFetcher
from .nuegressprofiles_fetcher import NUEgressProfilesFetcher
from .nuegressqospolicies_fetcher import NUEgressQOSPoliciesFetcher
from .nuenterprisenetworks_fetcher import NUEnterpriseNetworksFetcher
from .nuenterprisepermissions_fetcher import NUEnterprisePermissionsFetcher
from .nuenterpriseprofiles_fetcher import NUEnterpriseProfilesFetcher
from .nuenterprises_fetcher import NUEnterprisesFetcher
from .nuenterprisesecureddatas_fetcher import NUEnterpriseSecuredDatasFetcher
from .nuenterprisesecurities_fetcher import NUEnterpriseSecuritiesFetcher
from .nueventlogs_fetcher import NUEventLogsFetcher
from .nufirewallacls_fetcher import NUFirewallAclsFetcher
from .nufirewallrules_fetcher import NUFirewallRulesFetcher
from .nufloatingips_fetcher import NUFloatingIpsFetcher
from .nuforwardingpathlistentries_fetcher import NUForwardingPathListEntriesFetcher
from .nuforwardingpathlists_fetcher import NUForwardingPathListsFetcher
from .nugatewayredundantports_fetcher import NUGatewayRedundantPortsFetcher
from .nugateways_fetcher import NUGatewaysFetcher
from .nugatewaysecureddatas_fetcher import NUGatewaySecuredDatasFetcher
from .nugatewaysecurities_fetcher import NUGatewaySecuritiesFetcher
from .nugatewayslocations_fetcher import NUGatewaysLocationsFetcher
from .nugatewaytemplates_fetcher import NUGatewayTemplatesFetcher
from .nuglobalmetadatas_fetcher import NUGlobalMetadatasFetcher
from .nugroupkeyencryptionprofiles_fetcher import NUGroupKeyEncryptionProfilesFetcher
from .nugroups_fetcher import NUGroupsFetcher
from .nuhostinterfaces_fetcher import NUHostInterfacesFetcher
from .nuhscs_fetcher import NUHSCsFetcher
from .nuikecertificates_fetcher import NUIKECertificatesFetcher
from .nuikeencryptionprofiles_fetcher import NUIKEEncryptionprofilesFetcher
from .nuikegatewayconfigs_fetcher import NUIKEGatewayConfigsFetcher
from .nuikegatewayconnections_fetcher import NUIKEGatewayConnectionsFetcher
from .nuikegatewayprofiles_fetcher import NUIKEGatewayProfilesFetcher
from .nuikegateways_fetcher import NUIKEGatewaysFetcher
from .nuikepsks_fetcher import NUIKEPSKsFetcher
from .nuikesubnets_fetcher import NUIKESubnetsFetcher
from .nuinfrastructureaccessprofiles_fetcher import NUInfrastructureAccessProfilesFetcher
from .nuinfrastructureconfigs_fetcher import NUInfrastructureConfigsFetcher
from .nuinfrastructureevdfprofiles_fetcher import NUInfrastructureEVDFProfilesFetcher
from .nuinfrastructuregatewayprofiles_fetcher import NUInfrastructureGatewayProfilesFetcher
from .nuinfrastructurevscprofiles_fetcher import NUInfrastructureVscProfilesFetcher
from .nuingressaclentrytemplates_fetcher import NUIngressACLEntryTemplatesFetcher
from .nuingressacltemplates_fetcher import NUIngressACLTemplatesFetcher
from .nuingressadvfwdentrytemplates_fetcher import NUIngressAdvFwdEntryTemplatesFetcher
from .nuingressadvfwdtemplates_fetcher import NUIngressAdvFwdTemplatesFetcher
from .nuingressprofiles_fetcher import NUIngressProfilesFetcher
from .nuingressqospolicies_fetcher import NUIngressQOSPoliciesFetcher
from .nuipfilterprofiles_fetcher import NUIPFilterProfilesFetcher
from .nuipreservations_fetcher import NUIPReservationsFetcher
from .nuipv6filterprofiles_fetcher import NUIPv6FilterProfilesFetcher
from .nujobs_fetcher import NUJobsFetcher
from .nukeyservermembers_fetcher import NUKeyServerMembersFetcher
from .nukeyservermonitorencryptedseeds_fetcher import NUKeyServerMonitorEncryptedSeedsFetcher
from .nukeyservermonitors_fetcher import NUKeyServerMonitorsFetcher
from .nukeyservermonitorseeds_fetcher import NUKeyServerMonitorSeedsFetcher
from .nukeyservermonitorseks_fetcher import NUKeyServerMonitorSEKsFetcher
from .nul2domains_fetcher import NUL2DomainsFetcher
from .nul2domaintemplates_fetcher import NUL2DomainTemplatesFetcher
from .nul4servicegroups_fetcher import NUL4ServiceGroupsFetcher
from .nul4services_fetcher import NUL4ServicesFetcher
from .nul7applicationsignatures_fetcher import NUL7applicationsignaturesFetcher
from .nuldapconfigurations_fetcher import NULDAPConfigurationsFetcher
from .nulicenses_fetcher import NULicensesFetcher
from .nulicensestatus_fetcher import NULicenseStatusFetcher
from .nulinks_fetcher import NULinksFetcher
from .nulocations_fetcher import NULocationsFetcher
from .nulteinformations_fetcher import NULTEInformationsFetcher
from .nultestatistics_fetcher import NULtestatisticsFetcher
from .numacfilterprofiles_fetcher import NUMACFilterProfilesFetcher
from .numes_fetcher import NUMesFetcher
from .numetadatas_fetcher import NUMetadatasFetcher
from .numirrordestinations_fetcher import NUMirrorDestinationsFetcher
from .numonitoringports_fetcher import NUMonitoringPortsFetcher
from .numonitorscopes_fetcher import NUMonitorscopesFetcher
from .numulticastchannelmaps_fetcher import NUMultiCastChannelMapsFetcher
from .numulticastlists_fetcher import NUMultiCastListsFetcher
from .numulticastranges_fetcher import NUMultiCastRangesFetcher
from .numultinicvports_fetcher import NUMultiNICVPortsFetcher
from .nunatmapentries_fetcher import NUNATMapEntriesFetcher
from .nunetconfmanagers_fetcher import NUNetconfManagersFetcher
from .nunetconfprofiles_fetcher import NUNetconfProfilesFetcher
from .nunetconfsessions_fetcher import NUNetconfSessionsFetcher
from .nunetworklayouts_fetcher import NUNetworkLayoutsFetcher
from .nunetworkmacrogroups_fetcher import NUNetworkMacroGroupsFetcher
from .nunetworkperformancebindings_fetcher import NUNetworkPerformanceBindingsFetcher
from .nunetworkperformancemeasurements_fetcher import NUNetworkPerformanceMeasurementsFetcher
from .nunexthops_fetcher import NUNextHopsFetcher
from .nunsgatewaymonitors_fetcher import NUNSGatewayMonitorsFetcher
from .nunsgateways_fetcher import NUNSGatewaysFetcher
from .nunsgatewayscounts_fetcher import NUNSGatewaysCountsFetcher
from .nunsgatewaysummaries_fetcher import NUNSGatewaySummariesFetcher
from .nunsgatewaytemplates_fetcher import NUNSGatewayTemplatesFetcher
from .nunsggroups_fetcher import NUNSGGroupsFetcher
from .nunsginfos_fetcher import NUNSGInfosFetcher
from .nunsgpatchprofiles_fetcher import NUNSGPatchProfilesFetcher
from .nunsgroutingpolicybindings_fetcher import NUNSGRoutingPolicyBindingsFetcher
from .nunsgupgradeprofiles_fetcher import NUNSGUpgradeProfilesFetcher
from .nunsportinfos_fetcher import NUNSPortInfosFetcher
from .nunsports_fetcher import NUNSPortsFetcher
from .nunsporttemplates_fetcher import NUNSPortTemplatesFetcher
from .nunsredundantgatewaygroups_fetcher import NUNSRedundantGatewayGroupsFetcher
from .nuospfareas_fetcher import NUOSPFAreasFetcher
from .nuospfinstances_fetcher import NUOSPFInstancesFetcher
from .nuospfinterfaces_fetcher import NUOSPFInterfacesFetcher
from .nuoverlayaddresspools_fetcher import NUOverlayAddressPoolsFetcher
from .nuoverlaymanagementprofiles_fetcher import NUOverlayManagementProfilesFetcher
from .nuoverlaymanagementsubnetprofiles_fetcher import NUOverlayManagementSubnetProfilesFetcher
from .nuoverlaymirrordestinations_fetcher import NUOverlayMirrorDestinationsFetcher
from .nuoverlaymirrordestinationtemplates_fetcher import NUOverlayMirrorDestinationTemplatesFetcher
from .nuoverlaypatnatentries_fetcher import NUOverlayPATNATEntriesFetcher
from .nupatchs_fetcher import NUPatchsFetcher
from .nupatipentries_fetcher import NUPATIPEntriesFetcher
from .nupatmappers_fetcher import NUPATMappersFetcher
from .nupatnatpools_fetcher import NUPATNATPoolsFetcher
from .nuperformancemonitors_fetcher import NUPerformanceMonitorsFetcher
from .nupermissions_fetcher import NUPermissionsFetcher
from .nupgexpressions_fetcher import NUPGExpressionsFetcher
from .nupgexpressiontemplates_fetcher import NUPGExpressionTemplatesFetcher
from .nupolicydecisions_fetcher import NUPolicyDecisionsFetcher
from .nupolicyentries_fetcher import NUPolicyEntriesFetcher
from .nupolicygroupcategories_fetcher import NUPolicyGroupCategoriesFetcher
from .nupolicygroups_fetcher import NUPolicyGroupsFetcher
from .nupolicygrouptemplates_fetcher import NUPolicyGroupTemplatesFetcher
from .nupolicyobjectgroups_fetcher import NUPolicyObjectGroupsFetcher
from .nupolicystatements_fetcher import NUPolicyStatementsFetcher
from .nuportmappings_fetcher import NUPortMappingsFetcher
from .nuports_fetcher import NUPortsFetcher
from .nuporttemplates_fetcher import NUPortTemplatesFetcher
from .nuproxyarpfilters_fetcher import NUProxyARPFiltersFetcher
from .nupsnatpools_fetcher import NUPSNATPoolsFetcher
from .nupspatmaps_fetcher import NUPSPATMapsFetcher
from .nuptranslationmaps_fetcher import NUPTranslationMapsFetcher
from .nupublicnetworkmacros_fetcher import NUPublicNetworkMacrosFetcher
from .nuqospolicers_fetcher import NUQosPolicersFetcher
from .nuqoss_fetcher import NUQOSsFetcher
from .nuratelimiters_fetcher import NURateLimitersFetcher
from .nuredirectiontargets_fetcher import NURedirectionTargetsFetcher
from .nuredirectiontargettemplates_fetcher import NURedirectionTargetTemplatesFetcher
from .nuredundancygroups_fetcher import NURedundancyGroupsFetcher
from .nuredundantports_fetcher import NURedundantPortsFetcher
from .nuroutingpolicies_fetcher import NURoutingPoliciesFetcher
from .nusaasapplicationgroups_fetcher import NUSaaSApplicationGroupsFetcher
from .nusaasapplicationtypes_fetcher import NUSaaSApplicationTypesFetcher
from .nusapegressqosprofiles_fetcher import NUSAPEgressQoSProfilesFetcher
from .nusapingressqosprofiles_fetcher import NUSAPIngressQoSProfilesFetcher
from .nusharednetworkresources_fetcher import NUSharedNetworkResourcesFetcher
from .nushuntlinks_fetcher import NUShuntLinksFetcher
from .nusiteinfos_fetcher import NUSiteInfosFetcher
from .nuspatsourcespools_fetcher import NUSPATSourcesPoolsFetcher
from .nusshkeys_fetcher import NUSSHKeysFetcher
from .nussidconnections_fetcher import NUSSIDConnectionsFetcher
from .nustaticroutes_fetcher import NUStaticRoutesFetcher
from .nustatistics_fetcher import NUStatisticsFetcher
from .nustatisticspolicies_fetcher import NUStatisticsPoliciesFetcher
from .nustatscollectorinfos_fetcher import NUStatsCollectorInfosFetcher
from .nusubnets_fetcher import NUSubnetsFetcher
from .nusubnettemplates_fetcher import NUSubnetTemplatesFetcher
from .nusyslogdestinations_fetcher import NUSyslogDestinationsFetcher
from .nusystemconfigs_fetcher import NUSystemConfigsFetcher
from .nutcas_fetcher import NUTCAsFetcher
from .nutiers_fetcher import NUTiersFetcher
from .nutrunks_fetcher import NUTrunksFetcher
from .nuunderlays_fetcher import NUUnderlaysFetcher
from .nuuplinkconnections_fetcher import NUUplinkConnectionsFetcher
from .nuuplinkrds_fetcher import NUUplinkRDsFetcher
from .nuusercontexts_fetcher import NUUserContextsFetcher
from .nuusers_fetcher import NUUsersFetcher
from .nuvcenterclusters_fetcher import NUVCenterClustersFetcher
from .nuvcenterdatacenters_fetcher import NUVCenterDataCentersFetcher
from .nuvcentereamconfigs_fetcher import NUVCenterEAMConfigsFetcher
from .nuvcenterhypervisors_fetcher import NUVCenterHypervisorsFetcher
from .nuvcenters_fetcher import NUVCentersFetcher
from .nuvcentervrsconfigs_fetcher import NUVCenterVRSConfigsFetcher
from .nuvirtualfirewallpolicies_fetcher import NUVirtualFirewallPoliciesFetcher
from .nuvirtualfirewallrules_fetcher import NUVirtualFirewallRulesFetcher
from .nuvirtualips_fetcher import NUVirtualIPsFetcher
from .nuvlans_fetcher import NUVLANsFetcher
from .nuvlantemplates_fetcher import NUVLANTemplatesFetcher
from .nuvminterfaces_fetcher import NUVMInterfacesFetcher
from .nuvmresyncs_fetcher import NUVMResyncsFetcher
from .nuvms_fetcher import NUVMsFetcher
from .nuvnfcatalogs_fetcher import NUVNFCatalogsFetcher
from .nuvnfdescriptors_fetcher import NUVNFDescriptorsFetcher
from .nuvnfdomainmappings_fetcher import NUVNFDomainMappingsFetcher
from .nuvnfinterfacedescriptors_fetcher import NUVNFInterfaceDescriptorsFetcher
from .nuvnfinterfaces_fetcher import NUVNFInterfacesFetcher
from .nuvnfmetadatas_fetcher import NUVNFMetadatasFetcher
from .nuvnfs_fetcher import NUVNFsFetcher
from .nuvnfthresholdpolicies_fetcher import NUVNFThresholdPoliciesFetcher
from .nuvpnconnections_fetcher import NUVPNConnectionsFetcher
from .nuvportmirrors_fetcher import NUVPortMirrorsFetcher
from .nuvports_fetcher import NUVPortsFetcher
from .nuvrsaddressranges_fetcher import NUVRSAddressRangesFetcher
from .nuvrsmetrics_fetcher import NUVRSMetricsFetcher
from .nuvrsredeploymentpolicies_fetcher import NUVRSRedeploymentpoliciesFetcher
from .nuvrss_fetcher import NUVRSsFetcher
from .nuvscs_fetcher import NUVSCsFetcher
from .nuvsdcomponents_fetcher import NUVSDComponentsFetcher
from .nuvsds_fetcher import NUVSDsFetcher
from .nuvsgredundantports_fetcher import NUVsgRedundantPortsFetcher
from .nuvsps_fetcher import NUVSPsFetcher
from .nuwanservices_fetcher import NUWANServicesFetcher
from .nuwebcategories_fetcher import NUWebCategoriesFetcher
from .nuwebdomainnames_fetcher import NUWebDomainNamesFetcher
from .nuwirelessports_fetcher import NUWirelessPortsFetcher
from .nuzfbautoassignments_fetcher import NUZFBAutoAssignmentsFetcher
from .nuzfbrequests_fetcher import NUZFBRequestsFetcher
from .nuzones_fetcher import NUZonesFetcher
from .nuzonetemplates_fetcher import NUZoneTemplatesFetcher


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher

from bambou import NURESTObject


class NUInfrastructureEVDFProfile(NURESTObject):
    """ Represents a InfrastructureEVDFProfile in the VSD

        Notes:
            An Infrastructure eVDF Profile instance contains common parameters used to bootstrap instances of eVDF (encryption enabled virtual distributed firewall).
    """

    __rest_name__ = "infrastructureevdfprofile"
    __resource_name__ = "infrastructureevdfprofiles"

    
    ## Constants
    
    CONST_NUAGE_PLATFORM_KVM = "KVM"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_NUAGE_PLATFORM_KVM_LXC = "KVM_LXC"
    
    CONST_NUAGE_PLATFORM_KVM_K8S = "KVM_K8S"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    

    def __init__(self, **kwargs):
        """ Initializes a InfrastructureEVDFProfile instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> infrastructureevdfprofile = NUInfrastructureEVDFProfile(id=u'xxxx-xxx-xxx-xxx', name=u'InfrastructureEVDFProfile')
                >>> infrastructureevdfprofile = NUInfrastructureEVDFProfile(data=my_dict)
        """

        super(NUInfrastructureEVDFProfile, self).__init__()

        # Read/Write Attributes
        
        self._ntp_server_key = None
        self._ntp_server_key_id = None
        self._name = None
        self._last_updated_by = None
        self._active_controller = None
        self._service_ipv4_subnet = None
        self._description = None
        self._enterprise_id = None
        self._entity_scope = None
        self._proxy_dns_name = None
        self._use_two_factor = None
        self._standby_controller = None
        self._nuage_platform = None
        self._external_id = None
        
        self.expose_attribute(local_name="ntp_server_key", remote_name="NTPServerKey", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="ntp_server_key_id", remote_name="NTPServerKeyID", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="active_controller", remote_name="activeController", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="service_ipv4_subnet", remote_name="serviceIPv4Subnet", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="proxy_dns_name", remote_name="proxyDNSName", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="use_two_factor", remote_name="useTwoFactor", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="standby_controller", remote_name="standbyController", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="nuage_platform", remote_name="nuagePlatform", attribute_type=str, is_required=False, is_unique=False, choices=[u'KVM', u'KVM_K8S', u'KVM_LXC'])
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def ntp_server_key(self):
        """ Get ntp_server_key value.

            Notes:
                If set, this represents the security key for the Gateway to communicate with the NTP server (a VSC).

                
                This attribute is named `NTPServerKey` in VSD API.
                
        """
        return self._ntp_server_key

    @ntp_server_key.setter
    def ntp_server_key(self, value):
        """ Set ntp_server_key value.

            Notes:
                If set, this represents the security key for the Gateway to communicate with the NTP server (a VSC).

                
                This attribute is named `NTPServerKey` in VSD API.
                
        """
        self._ntp_server_key = value

    
    @property
    def ntp_server_key_id(self):
        """ Get ntp_server_key_id value.

            Notes:
                Corresponds to the key ID on the NTP server that matches the NTPServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and when value 0 is entered, it means that the NTP Key is not used (VSD/NSG only).

                
                This attribute is named `NTPServerKeyID` in VSD API.
                
        """
        return self._ntp_server_key_id

    @ntp_server_key_id.setter
    def ntp_server_key_id(self, value):
        """ Set ntp_server_key_id value.

            Notes:
                Corresponds to the key ID on the NTP server that matches the NTPServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and when value 0 is entered, it means that the NTP Key is not used (VSD/NSG only).

                
                This attribute is named `NTPServerKeyID` in VSD API.
                
        """
        self._ntp_server_key_id = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                The name of the profile instance.

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                The name of the profile instance.

                
        """
        self._name = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def active_controller(self):
        """ Get active_controller value.

            Notes:
                The IP address of the active Controller (VSC)

                
                This attribute is named `activeController` in VSD API.
                
        """
        return self._active_controller

    @active_controller.setter
    def active_controller(self, value):
        """ Set active_controller value.

            Notes:
                The IP address of the active Controller (VSC)

                
                This attribute is named `activeController` in VSD API.
                
        """
        self._active_controller = value

    
    @property
    def service_ipv4_subnet(self):
        """ Get service_ipv4_subnet value.

            Notes:
                K8 Service IPv4 Subnet

                
                This attribute is named `serviceIPv4Subnet` in VSD API.
                
        """
        return self._service_ipv4_subnet

    @service_ipv4_subnet.setter
    def service_ipv4_subnet(self, value):
        """ Set service_ipv4_subnet value.

            Notes:
                K8 Service IPv4 Subnet

                
                This attribute is named `serviceIPv4Subnet` in VSD API.
                
        """
        self._service_ipv4_subnet = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                A brief description of the infrastructure profile.

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                A brief description of the infrastructure profile.

                
        """
        self._description = value

    
    @property
    def enterprise_id(self):
        """ Get enterprise_id value.

            Notes:
                Enterprise/Organisation associated with this Profile instance.

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        """ Set enterprise_id value.

            Notes:
                Enterprise/Organisation associated with this Profile instance.

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        self._enterprise_id = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def proxy_dns_name(self):
        """ Get proxy_dns_name value.

            Notes:
                The DNS name of the proxy device acting as an entry point of eVDF instances to contact VSD.

                
                This attribute is named `proxyDNSName` in VSD API.
                
        """
        return self._proxy_dns_name

    @proxy_dns_name.setter
    def proxy_dns_name(self, value):
        """ Set proxy_dns_name value.

            Notes:
                The DNS name of the proxy device acting as an entry point of eVDF instances to contact VSD.

                
                This attribute is named `proxyDNSName` in VSD API.
                
        """
        self._proxy_dns_name = value

    
    @property
    def use_two_factor(self):
        """ Get use_two_factor value.

            Notes:
                A flag that indicates if two-factor is enabled or not when gateway instances inheriting from this profile are bootstrapped.

                
                This attribute is named `useTwoFactor` in VSD API.
                
        """
        return self._use_two_factor

    @use_two_factor.setter
    def use_two_factor(self, value):
        """ Set use_two_factor value.

            Notes:
                A flag that indicates if two-factor is enabled or not when gateway instances inheriting from this profile are bootstrapped.

                
                This attribute is named `useTwoFactor` in VSD API.
                
        """
        self._use_two_factor = value

    
    @property
    def standby_controller(self):
        """ Get standby_controller value.

            Notes:
                The IP address of the standby Controller (VSC)

                
                This attribute is named `standbyController` in VSD API.
                
        """
        return self._standby_controller

    @standby_controller.setter
    def standby_controller(self, value):
        """ Set standby_controller value.

            Notes:
                The IP address of the standby Controller (VSC)

                
                This attribute is named `standbyController` in VSD API.
                
        """
        self._standby_controller = value

    
    @property
    def nuage_platform(self):
        """ Get nuage_platform value.

            Notes:
                The Hypervisor Platform

                
                This attribute is named `nuagePlatform` in VSD API.
                
        """
        return self._nuage_platform

    @nuage_platform.setter
    def nuage_platform(self, value):
        """ Set nuage_platform value.

            Notes:
                The Hypervisor Platform

                
                This attribute is named `nuagePlatform` in VSD API.
                
        """
        self._nuage_platform = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUPermissionsFetcher


from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher

from bambou import NURESTObject


class NUJob(NURESTObject):
    """ Represents a Job in the VSD

        Notes:
            Represents JOB entity. The job API accepts a command and parameters and executes the job and returns the results. Jobs API are typically used for long running tasks.
    """

    __rest_name__ = "job"
    __resource_name__ = "jobs"

    
    ## Constants
    
    CONST_COMMAND_NSG_QUARANTINE = "NSG_QUARANTINE"
    
    CONST_COMMAND_PUBSUBNODE_AUDIT = "PUBSUBNODE_AUDIT"
    
    CONST_STATUS_SUCCESS = "SUCCESS"
    
    CONST_COMMAND_STATUS = "STATUS"
    
    CONST_COMMAND_RETRIEVE_ACTIVE_NSGS = "RETRIEVE_ACTIVE_NSGS"
    
    CONST_COMMAND_UNDEPLOY = "UNDEPLOY"
    
    CONST_COMMAND_RELOAD = "RELOAD"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_COMMAND_REJECT_ZFB_REQUEST = "REJECT_ZFB_REQUEST"
    
    CONST_COMMAND_NSG_NOTIFICATION_TEST = "NSG_NOTIFICATION_TEST"
    
    CONST_COMMAND_VCENTER_REMOVE_COMPUTERESOURCE_INSCOPE = "VCENTER_REMOVE_COMPUTERESOURCE_INSCOPE"
    
    CONST_COMMAND_NETCONF_FORCE_DEPLOY = "NETCONF_FORCE_DEPLOY"
    
    CONST_COMMAND_FORCE_KEYSERVER_UPDATE = "FORCE_KEYSERVER_UPDATE"
    
    CONST_COMMAND_START = "START"
    
    CONST_COMMAND_RELOAD_NSG_CONFIG = "RELOAD_NSG_CONFIG"
    
    CONST_COMMAND_CLOUD_SYNC = "CLOUD_SYNC"
    
    CONST_COMMAND_BEGIN_POLICY_CHANGES = "BEGIN_POLICY_CHANGES"
    
    CONST_COMMAND_VCENTER_SYNC = "VCENTER_SYNC"
    
    CONST_COMMAND_NETCONF_SYNC = "NETCONF_SYNC"
    
    CONST_COMMAND_ASSIGN_SELF_REBOOTSTRAP_REQ = "ASSIGN_SELF_REBOOTSTRAP_REQ"
    
    CONST_COMMAND_CLOUD_FORCE_CONFIG = "CLOUD_FORCE_CONFIG"
    
    CONST_COMMAND_EXPORT = "EXPORT"
    
    CONST_COMMAND_GET_ZFB_INFO = "GET_ZFB_INFO"
    
    CONST_COMMAND_FORCE_KEYSERVER_VSD_RESYNC = "FORCE_KEYSERVER_VSD_RESYNC"
    
    CONST_COMMAND_RECOVER_NSG = "RECOVER_NSG"
    
    CONST_COMMAND_BATCH_CRUD_REQUEST = "BATCH_CRUD_REQUEST"
    
    CONST_COMMAND_VCENTER_DELETE_AGENCY = "VCENTER_DELETE_AGENCY"
    
    CONST_STATUS_FAILED = "FAILED"
    
    CONST_COMMAND_APPLY_POLICY_CHANGES = "APPLY_POLICY_CHANGES"
    
    CONST_COMMAND_FORCE_KEYSERVER_UPDATE_ACK = "FORCE_KEYSERVER_UPDATE_ACK"
    
    CONST_COMMAND_NOTIFY_NSG_REGISTRATION = "NOTIFY_NSG_REGISTRATION"
    
    CONST_COMMAND_RESTART = "RESTART"
    
    CONST_COMMAND_REDEPLOY = "REDEPLOY"
    
    CONST_COMMAND_CERTIFICATE_NSG_REVOKE = "CERTIFICATE_NSG_REVOKE"
    
    CONST_COMMAND_NSG_VALIDATE_CONFIGURATION = "NSG_VALIDATE_CONFIGURATION"
    
    CONST_COMMAND_VCENTER_ADD_COMPUTERESOURCE_INSCOPE = "VCENTER_ADD_COMPUTERESOURCE_INSCOPE"
    
    CONST_COMMAND_APPLICATION_SIGNATURE_IMPORT = "APPLICATION_SIGNATURE_IMPORT"
    
    CONST_COMMAND_VCENTER_RECONNECT = "VCENTER_RECONNECT"
    
    CONST_COMMAND_CLEAR_MAC_MOVE_ALARMS = "CLEAR_MAC_MOVE_ALARMS"
    
    CONST_COMMAND_VCENTER_RELOAD = "VCENTER_RELOAD"
    
    CONST_COMMAND_NSG_REGISTRATION_INFO = "NSG_REGISTRATION_INFO"
    
    CONST_COMMAND_GATEWAY_AUDIT = "GATEWAY_AUDIT"
    
    CONST_COMMAND_NOTIFY_NSG_REGISTRATION_TEST = "NOTIFY_NSG_REGISTRATION_TEST"
    
    CONST_COMMAND_NOTIFY_NSG_REGISTRATION_ACK = "NOTIFY_NSG_REGISTRATION_ACK"
    
    CONST_COMMAND_STOP = "STOP"
    
    CONST_COMMAND_VCENTER_UPGRADE_VRS = "VCENTER_UPGRADE_VRS"
    
    CONST_COMMAND_IMPORT = "IMPORT"
    
    CONST_COMMAND_CLEAR_IPSEC_DATA = "CLEAR_IPSEC_DATA"
    
    CONST_COMMAND_RELOAD_GEO_REDUNDANT_INFO = "RELOAD_GEO_REDUNDANT_INFO"
    
    CONST_COMMAND_CERTIFICATE_NSG_RENEW = "CERTIFICATE_NSG_RENEW"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_STATUS_RUNNING = "RUNNING"
    
    CONST_COMMAND_VCENTER_SCRIPT_UPGRADE_VRS = "VCENTER_SCRIPT_UPGRADE_VRS"
    
    CONST_COMMAND_DEPLOY = "DEPLOY"
    
    CONST_COMMAND_NSG_LIFT_QUARANTINE = "NSG_LIFT_QUARANTINE"
    
    CONST_COMMAND_SYNC = "SYNC"
    
    CONST_COMMAND_KEYSERVER_NOTIFICATION_TEST = "KEYSERVER_NOTIFICATION_TEST"
    
    CONST_COMMAND_DISCARD_POLICY_CHANGES = "DISCARD_POLICY_CHANGES"
    
    CONST_COMMAND_VCENTER_MARK_AGENT_VM_AVAILABLE = "VCENTER_MARK_AGENT_VM_AVAILABLE"
    
    CONST_COMMAND_SAAS_APPLICATION_TYPE = "SAAS_APPLICATION_TYPE"
    
    

    def __init__(self, **kwargs):
        """ Initializes a Job instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> job = NUJob(id=u'xxxx-xxx-xxx-xxx', name=u'Job')
                >>> job = NUJob(data=my_dict)
        """

        super(NUJob, self).__init__()

        # Read/Write Attributes
        
        self._parameters = None
        self._last_updated_by = None
        self._last_updated_date = None
        self._result = None
        self._embedded_metadata = None
        self._entity_scope = None
        self._command = None
        self._creation_date = None
        self._progress = None
        self._assoc_entity_type = None
        self._status = None
        self._owner = None
        self._external_id = None
        
        self.expose_attribute(local_name="parameters", remote_name="parameters", attribute_type=dict, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="result", remote_name="result", attribute_type=dict, is_required=False, is_unique=False)
        self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="command", remote_name="command", attribute_type=str, is_required=True, is_unique=False, choices=[u'APPLICATION_SIGNATURE_IMPORT', u'APPLY_POLICY_CHANGES', u'ASSIGN_SELF_REBOOTSTRAP_REQ', u'BATCH_CRUD_REQUEST', u'BEGIN_POLICY_CHANGES', u'CERTIFICATE_NSG_RENEW', u'CERTIFICATE_NSG_REVOKE', u'CLEAR_IPSEC_DATA', u'CLEAR_MAC_MOVE_ALARMS', u'CLOUD_FORCE_CONFIG', u'CLOUD_SYNC', u'DEPLOY', u'DISCARD_POLICY_CHANGES', u'EXPORT', u'FORCE_KEYSERVER_UPDATE', u'FORCE_KEYSERVER_UPDATE_ACK', u'FORCE_KEYSERVER_VSD_RESYNC', u'GATEWAY_AUDIT', u'GET_ZFB_INFO', u'IMPORT', u'KEYSERVER_NOTIFICATION_TEST', u'NETCONF_FORCE_DEPLOY', u'NETCONF_SYNC', u'NOTIFY_NSG_REGISTRATION', u'NOTIFY_NSG_REGISTRATION_ACK', u'NOTIFY_NSG_REGISTRATION_TEST', u'NSG_LIFT_QUARANTINE', u'NSG_NOTIFICATION_TEST', u'NSG_QUARANTINE', u'NSG_REGISTRATION_INFO', u'NSG_VALIDATE_CONFIGURATION', u'PUBSUBNODE_AUDIT', u'RECOVER_NSG', u'REDEPLOY', u'REJECT_ZFB_REQUEST', u'RELOAD', u'RELOAD_GEO_REDUNDANT_INFO', u'RELOAD_NSG_CONFIG', u'RESTART', u'RETRIEVE_ACTIVE_NSGS', u'SAAS_APPLICATION_TYPE', u'START', u'STATUS', u'STOP', u'SYNC', u'UNDEPLOY', u'VCENTER_ADD_COMPUTERESOURCE_INSCOPE', u'VCENTER_DELETE_AGENCY', u'VCENTER_MARK_AGENT_VM_AVAILABLE', u'VCENTER_RECONNECT', u'VCENTER_RELOAD', u'VCENTER_REMOVE_COMPUTERESOURCE_INSCOPE', u'VCENTER_SCRIPT_UPGRADE_VRS', u'VCENTER_SYNC', u'VCENTER_UPGRADE_VRS'])
        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="progress", remote_name="progress", attribute_type=float, is_required=False, is_unique=False)
        self.expose_attribute(local_name="assoc_entity_type", remote_name="assocEntityType", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'FAILED', u'RUNNING', u'SUCCESS'])
        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def parameters(self):
        """ Get parameters value.

            Notes:
                Additional arguments required for the specific command. Differs based on types of command.

                
        """
        return self._parameters

    @parameters.setter
    def parameters(self, value):
        """ Set parameters value.

            Notes:
                Additional arguments required for the specific command. Differs based on types of command.

                
        """
        self._parameters = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def last_updated_date(self):
        """ Get last_updated_date value.

            Notes:
                Time stamp when this object was last updated.

                
                This attribute is named `lastUpdatedDate` in VSD API.
                
        """
        return self._last_updated_date

    @last_updated_date.setter
    def last_updated_date(self, value):
        """ Set last_updated_date value.

            Notes:
                Time stamp when this object was last updated.

                
                This attribute is named `lastUpdatedDate` in VSD API.
                
        """
        self._last_updated_date = value

    
    @property
    def result(self):
        """ Get result value.

            Notes:
                Results from the execution of the job

                
        """
        return self._result

    @result.setter
    def result(self, value):
        """ Set result value.

            Notes:
                Results from the execution of the job

                
        """
        self._result = value

    
    @property
    def embedded_metadata(self):
        """ Get embedded_metadata value.

            Notes:
                Metadata objects associated with this entity. This will contain a list of Metadata objects if the API request is made using the special flag to enable the embedded Metadata feature. Only a maximum of Metadata objects is returned based on the value set in the system configuration.

                
                This attribute is named `embeddedMetadata` in VSD API.
                
        """
        return self._embedded_metadata

    @embedded_metadata.setter
    def embedded_metadata(self, value):
        """ Set embedded_metadata value.

            Notes:
                Metadata objects associated with this entity. This will contain a list of Metadata objects if the API request is made using the special flag to enable the embedded Metadata feature. Only a maximum of Metadata objects is returned based on the value set in the system configuration.

                
                This attribute is named `embeddedMetadata` in VSD API.
                
        """
        self._embedded_metadata = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def command(self):
        """ Get command value.

            Notes:
                Name of the command.

                
        """
        return self._command

    @command.setter
    def command(self, value):
        """ Set command value.

            Notes:
                Name of the command.

                
        """
        self._command = value

    
    @property
    def creation_date(self):
        """ Get creation_date value.

            Notes:
                Time stamp when this object was created.

                
                This attribute is named `creationDate` in VSD API.
                
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, value):
        """ Set creation_date value.

            Notes:
                Time stamp when this object was created.

                
                This attribute is named `creationDate` in VSD API.
                
        """
        self._creation_date = value

    
    @property
    def progress(self):
        """ Get progress value.

            Notes:
                Indicates the progress of the job as a faction. eg : 0.5 means 50% done.

                
        """
        return self._progress

    @progress.setter
    def progress(self, value):
        """ Set progress value.

            Notes:
                Indicates the progress of the job as a faction. eg : 0.5 means 50% done.

                
        """
        self._progress = value

    
    @property
    def assoc_entity_type(self):
        """ Get assoc_entity_type value.

            Notes:
                Entity with which this job is associated Refer to API section for supported types.

                
                This attribute is named `assocEntityType` in VSD API.
                
        """
        return self._assoc_entity_type

    @assoc_entity_type.setter
    def assoc_entity_type(self, value):
        """ Set assoc_entity_type value.

            Notes:
                Entity with which this job is associated Refer to API section for supported types.

                
                This attribute is named `assocEntityType` in VSD API.
                
        """
        self._assoc_entity_type = value

    
    @property
    def status(self):
        """ Get status value.

            Notes:
                Current status of the job. Possible values are RUNNING, FAILED, SUCCESS, .

                
        """
        return self._status

    @status.setter
    def status(self, value):
        """ Set status value.

            Notes:
                Current status of the job. Possible values are RUNNING, FAILED, SUCCESS, .

                
        """
        self._status = value

    
    @property
    def owner(self):
        """ Get owner value.

            Notes:
                Identifies the user that has created this object.

                
        """
        return self._owner

    @owner.setter
    def owner(self, value):
        """ Set owner value.

            Notes:
                Identifies the user that has created this object.

                
        """
        self._owner = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUPermissionsFetcher


from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher


from .fetchers import NUVPortsFetcher

from bambou import NURESTObject


class NUOverlayMirrorDestination(NURESTObject):
    """ Represents a OverlayMirrorDestination in the VSD

        Notes:
            Overlay mirror destinations are pointed to by advanced forwarding policies as the destination for redirected traffic. Targets can be of two types, L3 or virtual wire. For L3 targets a virtual IP should be provided as it allows the system to track among which of the end-points belonging to the overlay mirror destination is the active one. For this type of redirect the packet's destination MAC address is changed to match that of the Virtual IP. For virtual-wire redirection targets, the packets are untouched and forwarded directly to the end-point.
    """

    __rest_name__ = "overlaymirrordestination"
    __resource_name__ = "overlaymirrordestinations"

    
    ## Constants
    
    CONST_DESTINATION_TYPE_REDIRECTION_TARGET = "REDIRECTION_TARGET"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_DESTINATION_TYPE_OVERLAY_MIRROR_DESTINATION = "OVERLAY_MIRROR_DESTINATION"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_END_POINT_TYPE_NONE = "NONE"
    
    CONST_TRIGGER_TYPE_NONE = "NONE"
    
    CONST_END_POINT_TYPE_VIRTUAL_WIRE = "VIRTUAL_WIRE"
    
    CONST_TRIGGER_TYPE_GARP = "GARP"
    
    

    def __init__(self, **kwargs):
        """ Initializes a OverlayMirrorDestination instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> overlaymirrordestination = NUOverlayMirrorDestination(id=u'xxxx-xxx-xxx-xxx', name=u'OverlayMirrorDestination')
                >>> overlaymirrordestination = NUOverlayMirrorDestination(data=my_dict)
        """

        super(NUOverlayMirrorDestination, self).__init__()

        # Read/Write Attributes
        
        self._esi = None
        self._name = None
        self._last_updated_by = None
        self._last_updated_date = None
        self._redundancy_enabled = None
        self._template_id = None
        self._description = None
        self._destination_type = None
        self._virtual_network_id = None
        self._embedded_metadata = None
        self._end_point_type = None
        self._entity_scope = None
        self._creation_date = None
        self._trigger_type = None
        self._owner = None
        self._external_id = None
        
        self.expose_attribute(local_name="esi", remote_name="ESI", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="redundancy_enabled", remote_name="redundancyEnabled", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="destination_type", remote_name="destinationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'OVERLAY_MIRROR_DESTINATION', u'REDIRECTION_TARGET'])
        self.expose_attribute(local_name="virtual_network_id", remote_name="virtualNetworkID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name="end_point_type", remote_name="endPointType", attribute_type=str, is_required=True, is_unique=False, choices=[u'NONE', u'VIRTUAL_WIRE'])
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="trigger_type", remote_name="triggerType", attribute_type=str, is_required=False, is_unique=False, choices=[u'GARP', u'NONE'])
        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="member")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def esi(self):
        """ Get esi value.

            Notes:
                ESI id, globally unique

                
                This attribute is named `ESI` in VSD API.
                
        """
        return self._esi

    @esi.setter
    def esi(self, value):
        """ Set esi value.

            Notes:
                ESI id, globally unique

                
                This attribute is named `ESI` in VSD API.
                
        """
        self._esi = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                Name of this overlay mirror destination

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                Name of this overlay mirror destination

                
        """
        self._name = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def last_updated_date(self):
        """ Get last_updated_date value.

            Notes:
                Time stamp when this object was last updated.

                
                This attribute is named `lastUpdatedDate` in VSD API.
                
        """
        return self._last_updated_date

    @last_updated_date.setter
    def last_updated_date(self, value):
        """ Set last_updated_date value.

            Notes:
                Time stamp when this object was last updated.

                
                This attribute is named `lastUpdatedDate` in VSD API.
                
        """
        self._last_updated_date = value

    
    @property
    def redundancy_enabled(self):
        """ Get redundancy_enabled value.

            Notes:
                Allow/Disallow redundant appliances and VIP

                
                This attribute is named `redundancyEnabled` in VSD API.
                
        """
        return self._redundancy_enabled

    @redundancy_enabled.setter
    def redundancy_enabled(self, value):
        """ Set redundancy_enabled value.

            Notes:
                Allow/Disallow redundant appliances and VIP

                
                This attribute is named `redundancyEnabled` in VSD API.
                
        """
        self._redundancy_enabled = value

    
    @property
    def template_id(self):
        """ Get template_id value.

            Notes:
                Template to which this overlay mirror destination belongs to

                
                This attribute is named `templateID` in VSD API.
                
        """
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        """ Set template_id value.

            Notes:
                Template to which this overlay mirror destination belongs to

                
                This attribute is named `templateID` in VSD API.
                
        """
        self._template_id = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                Description of this overlay mirror destination

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                Description of this overlay mirror destination

                
        """
        self._description = value

    
    @property
    def destination_type(self):
        """ Get destination_type value.

            Notes:
                Determines the type of destination : redirection target or overlay mirror destination

                
                This attribute is named `destinationType` in VSD API.
                
        """
        return self._destination_type

    @destination_type.setter
    def destination_type(self, value):
        """ Set destination_type value.

            Notes:
                Determines the type of destination : redirection target or overlay mirror destination

                
                This attribute is named `destinationType` in VSD API.
                
        """
        self._destination_type = value

    
    @property
    def virtual_network_id(self):
        """ Get virtual_network_id value.

            Notes:
                Auto Generated by VSD. Each overlay mirror destination with redundancy=enable and EndpointType != none will have a globally unique ESI & VNID generated by VSD

                
                This attribute is named `virtualNetworkID` in VSD API.
                
        """
        return self._virtual_network_id

    @virtual_network_id.setter
    def virtual_network_id(self, value):
        """ Set virtual_network_id value.

            Notes:
                Auto Generated by VSD. Each overlay mirror destination with redundancy=enable and EndpointType != none will have a globally unique ESI & VNID generated by VSD

                
                This attribute is named `virtualNetworkID` in VSD API.
                
        """
        self._virtual_network_id = value

    
    @property
    def embedded_metadata(self):
        """ Get embedded_metadata value.

            Notes:
                Metadata objects associated with this entity. This will contain a list of Metadata objects if the API request is made using the special flag to enable the embedded Metadata feature. Only a maximum of Metadata objects is returned based on the value set in the system configuration.

                
                This attribute is named `embeddedMetadata` in VSD API.
                
        """
        return self._embedded_metadata

    @embedded_metadata.setter
    def embedded_metadata(self, value):
        """ Set embedded_metadata value.

            Notes:
                Metadata objects associated with this entity. This will contain a list of Metadata objects if the API request is made using the special flag to enable the embedded Metadata feature. Only a maximum of Metadata objects is returned based on the value set in the system configuration.

                
                This attribute is named `embeddedMetadata` in VSD API.
                
        """
        self._embedded_metadata = value

    
    @property
    def end_point_type(self):
        """ Get end_point_type value.

            Notes:
                EndPointType is an enum. It defines the type of header rewrite and forwarding performed by VRS when the endpoint is used as a mirror destination. Possible value is VIRTUAL_WIRE

                
                This attribute is named `endPointType` in VSD API.
                
        """
        return self._end_point_type

    @end_point_type.setter
    def end_point_type(self, value):
        """ Set end_point_type value.

            Notes:
                EndPointType is an enum. It defines the type of header rewrite and forwarding performed by VRS when the endpoint is used as a mirror destination. Possible value is VIRTUAL_WIRE

                
                This attribute is named `endPointType` in VSD API.
                
        """
        self._end_point_type = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def creation_date(self):
        """ Get creation_date value.

            Notes:
                Time stamp when this object was created.

                
                This attribute is named `creationDate` in VSD API.
                
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, value):
        """ Set creation_date value.

            Notes:
                Time stamp when this object was created.

                
                This attribute is named `creationDate` in VSD API.
                
        """
        self._creation_date = value

    
    @property
    def trigger_type(self):
        """ Get trigger_type value.

            Notes:
                Trigger type, THIS IS READ ONLY. Possible values are NONE, GARP.

                
                This attribute is named `triggerType` in VSD API.
                
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, value):
        """ Set trigger_type value.

            Notes:
                Trigger type, THIS IS READ ONLY. Possible values are NONE, GARP.

                
                This attribute is named `triggerType` in VSD API.
                
        """
        self._trigger_type = value

    
    @property
    def owner(self):
        """ Get owner value.

            Notes:
                Identifies the user that has created this object.

                
        """
        return self._owner

    @owner.setter
    def owner(self, value):
        """ Set owner value.

            Notes:
                Identifies the user that has created this object.

                
        """
        self._owner = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from setuptools import setup
import os

packages = ['vspk', 'vspk.cli']
resources = []
api_version_path = "./vspk"

for version_folder in os.listdir(api_version_path):

    if os.path.isfile("%s/%s" % (api_version_path, version_folder)):
        continue

    if version_folder == "cli":
        continue

    packages.append("vspk.%s" % version_folder)
    packages.append("vspk.%s.fetchers" % version_folder)

    if os.path.exists('vspk/%s/resources' % version_folder):
        resources.append(('vspk/%s/resources' % version_folder, ['vspk/%s/resources/attrs_defaults.ini' % version_folder]))

setup(
    name='vspk',
    version="20.10.2",
    url='http://nuagenetworks.net/',
    author='nuage networks',
    author_email='opensource@nuagenetworks.net',
    packages=packages,
    description='SDK for the VSD API',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    license='BSD-3',
    include_package_data=True,
    install_requires=[line for line in open('requirements.txt')],
    data_files=resources,
    entry_points={
        'console_scripts': [
            'vsd = vspk.cli.cli:main']
    }
)


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



from bambou import NURESTObject


class NUSyslogDestination(NURESTObject):
    """ Represents a SyslogDestination in the VSD

        Notes:
            Syslog Destination provides the definition for a Syslog Server Destination
    """

    __rest_name__ = "syslogdestination"
    __resource_name__ = "syslogdestinations"

    
    ## Constants
    
    CONST_IP_TYPE_IPV4 = "IPV4"
    
    CONST_TYPE_UDP = "UDP"
    
    

    def __init__(self, **kwargs):
        """ Initializes a SyslogDestination instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> syslogdestination = NUSyslogDestination(id=u'xxxx-xxx-xxx-xxx', name=u'SyslogDestination')
                >>> syslogdestination = NUSyslogDestination(data=my_dict)
        """

        super(NUSyslogDestination, self).__init__()

        # Read/Write Attributes
        
        self._ip_address = None
        self._ip_type = None
        self._name = None
        self._description = None
        self._port = None
        self._type = None
        
        self.expose_attribute(local_name="ip_address", remote_name="IPAddress", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4'])
        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="port", remote_name="port", attribute_type=int, is_required=True, is_unique=False)
        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'UDP'])
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def ip_address(self):
        """ Get ip_address value.

            Notes:
                The IP Address of the syslog server

                
                This attribute is named `IPAddress` in VSD API.
                
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, value):
        """ Set ip_address value.

            Notes:
                The IP Address of the syslog server

                
                This attribute is named `IPAddress` in VSD API.
                
        """
        self._ip_address = value

    
    @property
    def ip_type(self):
        """ Get ip_type value.

            Notes:
                IP Type of the syslog IP Address. Supported values: 'IPV4'

                
                This attribute is named `IPType` in VSD API.
                
        """
        return self._ip_type

    @ip_type.setter
    def ip_type(self, value):
        """ Set ip_type value.

            Notes:
                IP Type of the syslog IP Address. Supported values: 'IPV4'

                
                This attribute is named `IPType` in VSD API.
                
        """
        self._ip_type = value

    
    @property
    def name(self):
        """ Get name value.

            Notes:
                Name of the syslog server

                
        """
        return self._name

    @name.setter
    def name(self, value):
        """ Set name value.

            Notes:
                Name of the syslog server

                
        """
        self._name = value

    
    @property
    def description(self):
        """ Get description value.

            Notes:
                A detailed description of the syslog server

                
        """
        return self._description

    @description.setter
    def description(self, value):
        """ Set description value.

            Notes:
                A detailed description of the syslog server

                
        """
        self._description = value

    
    @property
    def port(self):
        """ Get port value.

            Notes:
                The port the syslog server is configured on

                
        """
        return self._port

    @port.setter
    def port(self, value):
        """ Set port value.

            Notes:
                The port the syslog server is configured on

                
        """
        self._port = value

    
    @property
    def type(self):
        """ Get type value.

            Notes:
                The protocol type of the syslog server. Supported values: 'UDP'

                
        """
        return self._type

    @type.setter
    def type(self, value):
        """ Set type value.

            Notes:
                The protocol type of the syslog server. Supported values: 'UDP'

                
        """
        self._type = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUMetadatasFetcher


from .fetchers import NUBFDSessionsFetcher


from .fetchers import NUGlobalMetadatasFetcher

from bambou import NURESTObject


class NUBRConnection(NURESTObject):
    """ Represents a BRConnection in the VSD

        Notes:
            Configuration of VNS Gateway Border Router connection
    """

    __rest_name__ = "brconnection"
    __resource_name__ = "brconnections"

    
    ## Constants
    
    CONST_ADVERTISEMENT_CRITERIA_OPERATIONAL_LINK = "OPERATIONAL_LINK"
    
    CONST_ADVERTISEMENT_CRITERIA_BFD = "BFD"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    CONST_MODE_STATIC = "Static"
    
    CONST_ADDRESS_FAMILY_IPV6 = "IPV6"
    
    CONST_ADDRESS_FAMILY_IPV4 = "IPV4"
    
    

    def __init__(self, **kwargs):
        """ Initializes a BRConnection instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> brconnection = NUBRConnection(id=u'xxxx-xxx-xxx-xxx', name=u'BRConnection')
                >>> brconnection = NUBRConnection(data=my_dict)
        """

        super(NUBRConnection, self).__init__()

        # Read/Write Attributes
        
        self._dns_address = None
        self._dns_address_v6 = None
        self._last_updated_by = None
        self._gateway = None
        self._gateway_v6 = None
        self._address = None
        self._address_family = None
        self._address_v6 = None
        self._advertisement_criteria = None
        self._netmask = None
        self._inherited = None
        self._entity_scope = None
        self._mode = None
        self._uplink_id = None
        self._external_id = None
        
        self.expose_attribute(local_name="dns_address", remote_name="DNSAddress", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="dns_address_v6", remote_name="DNSAddressV6", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="gateway_v6", remote_name="gatewayV6", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="address_family", remote_name="addressFamily", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
        self.expose_attribute(local_name="address_v6", remote_name="addressV6", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="advertisement_criteria", remote_name="advertisementCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'BFD', u'OPERATIONAL_LINK'])
        self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="inherited", remote_name="inherited", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="mode", remote_name="mode", attribute_type=str, is_required=False, is_unique=False, choices=[u'Static'])
        self.expose_attribute(local_name="uplink_id", remote_name="uplinkID", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        

        # Fetchers
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.bfd_sessions = NUBFDSessionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def dns_address(self):
        """ Get dns_address value.

            Notes:
                DNS Address for the vlan

                
                This attribute is named `DNSAddress` in VSD API.
                
        """
        return self._dns_address

    @dns_address.setter
    def dns_address(self, value):
        """ Set dns_address value.

            Notes:
                DNS Address for the vlan

                
                This attribute is named `DNSAddress` in VSD API.
                
        """
        self._dns_address = value

    
    @property
    def dns_address_v6(self):
        """ Get dns_address_v6 value.

            Notes:
                DNS IPv6 Address

                
                This attribute is named `DNSAddressV6` in VSD API.
                
        """
        return self._dns_address_v6

    @dns_address_v6.setter
    def dns_address_v6(self, value):
        """ Set dns_address_v6 value.

            Notes:
                DNS IPv6 Address

                
                This attribute is named `DNSAddressV6` in VSD API.
                
        """
        self._dns_address_v6 = value

    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def gateway(self):
        """ Get gateway value.

            Notes:
                IP address of the gateway bound to the VLAN.

                
        """
        return self._gateway

    @gateway.setter
    def gateway(self, value):
        """ Set gateway value.

            Notes:
                IP address of the gateway bound to the VLAN.

                
        """
        self._gateway = value

    
    @property
    def gateway_v6(self):
        """ Get gateway_v6 value.

            Notes:
                IPv6 address of the gateway bound to the port.

                
                This attribute is named `gatewayV6` in VSD API.
                
        """
        return self._gateway_v6

    @gateway_v6.setter
    def gateway_v6(self, value):
        """ Set gateway_v6 value.

            Notes:
                IPv6 address of the gateway bound to the port.

                
                This attribute is named `gatewayV6` in VSD API.
                
        """
        self._gateway_v6 = value

    
    @property
    def address(self):
        """ Get address value.

            Notes:
                Static IP address for the VLAN on which the BR Connection is created.

                
        """
        return self._address

    @address.setter
    def address(self, value):
        """ Set address value.

            Notes:
                Static IP address for the VLAN on which the BR Connection is created.

                
        """
        self._address = value

    
    @property
    def address_family(self):
        """ Get address_family value.

            Notes:
                IP address family of this BRConnection

                
                This attribute is named `addressFamily` in VSD API.
                
        """
        return self._address_family

    @address_family.setter
    def address_family(self, value):
        """ Set address_family value.

            Notes:
                IP address family of this BRConnection

                
                This attribute is named `addressFamily` in VSD API.
                
        """
        self._address_family = value

    
    @property
    def address_v6(self):
        """ Get address_v6 value.

            Notes:
                IPv6 address for static configuration on the BR Connection instance.

                
                This attribute is named `addressV6` in VSD API.
                
        """
        return self._address_v6

    @address_v6.setter
    def address_v6(self, value):
        """ Set address_v6 value.

            Notes:
                IPv6 address for static configuration on the BR Connection instance.

                
                This attribute is named `addressV6` in VSD API.
                
        """
        self._address_v6 = value

    
    @property
    def advertisement_criteria(self):
        """ Get advertisement_criteria value.

            Notes:
                Advertisement Criteria for Traffic Flow on a BR Connection.

                
                This attribute is named `advertisementCriteria` in VSD API.
                
        """
        return self._advertisement_criteria

    @advertisement_criteria.setter
    def advertisement_criteria(self, value):
        """ Set advertisement_criteria value.

            Notes:
                Advertisement Criteria for Traffic Flow on a BR Connection.

                
                This attribute is named `advertisementCriteria` in VSD API.
                
        """
        self._advertisement_criteria = value

    
    @property
    def netmask(self):
        """ Get netmask value.

            Notes:
                network mask

                
        """
        return self._netmask

    @netmask.setter
    def netmask(self, value):
        """ Set netmask value.

            Notes:
                network mask

                
        """
        self._netmask = value

    
    @property
    def inherited(self):
        """ Get inherited value.

            Notes:
                This flag will determine if the abstract connection is inherited from the instance template

                
        """
        return self._inherited

    @inherited.setter
    def inherited(self, value):
        """ Set inherited value.

            Notes:
                This flag will determine if the abstract connection is inherited from the instance template

                
        """
        self._inherited = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def mode(self):
        """ Get mode value.

            Notes:
                Connection mode: Only static is allowed on a Bridge Router Connection.

                
        """
        return self._mode

    @mode.setter
    def mode(self, value):
        """ Set mode value.

            Notes:
                Connection mode: Only static is allowed on a Bridge Router Connection.

                
        """
        self._mode = value

    
    @property
    def uplink_id(self):
        """ Get uplink_id value.

            Notes:
                Internally generated ID in the range that idenitifies the uplink within the context of NSG.

                
                This attribute is named `uplinkID` in VSD API.
                
        """
        return self._uplink_id

    @uplink_id.setter
    def uplink_id(self, value):
        """ Set uplink_id value.

            Notes:
                Internally generated ID in the range that idenitifies the uplink within the context of NSG.

                
                This attribute is named `uplinkID` in VSD API.
                
        """
        self._uplink_id = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUMetadatasFetcher


from .fetchers import NUGlobalMetadatasFetcher


from .fetchers import NUStatisticsFetcher


from .fetchers import NUStatisticsPoliciesFetcher

from bambou import NURESTObject


class NUAddressMap(NURESTObject):
    """ Represents a AddressMap in the VSD

        Notes:
            Defines an address mapping between a private IP and a port with a public IP address and port.
    """

    __rest_name__ = "addressmap"
    __resource_name__ = "addressmaps"

    
    ## Constants
    
    CONST_TYPE_ONE_TO_ONE_NAT = "ONE_TO_ONE_NAT"
    
    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
    
    CONST_TYPE_MANY_TO_ONE_PAT = "MANY_TO_ONE_PAT"
    
    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
    
    

    def __init__(self, **kwargs):
        """ Initializes a AddressMap instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> addressmap = NUAddressMap(id=u'xxxx-xxx-xxx-xxx', name=u'AddressMap')
                >>> addressmap = NUAddressMap(data=my_dict)
        """

        super(NUAddressMap, self).__init__()

        # Read/Write Attributes
        
        self._last_updated_by = None
        self._entity_scope = None
        self._private_ip = None
        self._private_port = None
        self._associated_patnat_pool_id = None
        self._public_ip = None
        self._public_port = None
        self._external_id = None
        self._type = None
        
        self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
        self.expose_attribute(local_name="private_ip", remote_name="privateIP", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name="private_port", remote_name="privatePort", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_patnat_pool_id", remote_name="associatedPATNATPoolID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="public_ip", remote_name="publicIP", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="public_port", remote_name="publicPort", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'MANY_TO_ONE_PAT', u'ONE_TO_ONE_NAT'])
        

        # Fetchers
        
        
        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
        
        
        self.statistics_policies = NUStatisticsPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def last_updated_by(self):
        """ Get last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, value):
        """ Set last_updated_by value.

            Notes:
                ID of the user who last updated the object.

                
                This attribute is named `lastUpdatedBy` in VSD API.
                
        """
        self._last_updated_by = value

    
    @property
    def entity_scope(self):
        """ Get entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        return self._entity_scope

    @entity_scope.setter
    def entity_scope(self, value):
        """ Set entity_scope value.

            Notes:
                Specify if scope of entity is Data center or Enterprise level

                
                This attribute is named `entityScope` in VSD API.
                
        """
        self._entity_scope = value

    
    @property
    def private_ip(self):
        """ Get private_ip value.

            Notes:
                Private IP address of the interface

                
                This attribute is named `privateIP` in VSD API.
                
        """
        return self._private_ip

    @private_ip.setter
    def private_ip(self, value):
        """ Set private_ip value.

            Notes:
                Private IP address of the interface

                
                This attribute is named `privateIP` in VSD API.
                
        """
        self._private_ip = value

    
    @property
    def private_port(self):
        """ Get private_port value.

            Notes:
                None

                
                This attribute is named `privatePort` in VSD API.
                
        """
        return self._private_port

    @private_port.setter
    def private_port(self, value):
        """ Set private_port value.

            Notes:
                None

                
                This attribute is named `privatePort` in VSD API.
                
        """
        self._private_port = value

    
    @property
    def associated_patnat_pool_id(self):
        """ Get associated_patnat_pool_id value.

            Notes:
                Read Only - Indicates which PATNATPool this entry belongs to

                
                This attribute is named `associatedPATNATPoolID` in VSD API.
                
        """
        return self._associated_patnat_pool_id

    @associated_patnat_pool_id.setter
    def associated_patnat_pool_id(self, value):
        """ Set associated_patnat_pool_id value.

            Notes:
                Read Only - Indicates which PATNATPool this entry belongs to

                
                This attribute is named `associatedPATNATPoolID` in VSD API.
                
        """
        self._associated_patnat_pool_id = value

    
    @property
    def public_ip(self):
        """ Get public_ip value.

            Notes:
                Public IP address of the interface

                
                This attribute is named `publicIP` in VSD API.
                
        """
        return self._public_ip

    @public_ip.setter
    def public_ip(self, value):
        """ Set public_ip value.

            Notes:
                Public IP address of the interface

                
                This attribute is named `publicIP` in VSD API.
                
        """
        self._public_ip = value

    
    @property
    def public_port(self):
        """ Get public_port value.

            Notes:
                None

                
                This attribute is named `publicPort` in VSD API.
                
        """
        return self._public_port

    @public_port.setter
    def public_port(self, value):
        """ Set public_port value.

            Notes:
                None

                
                This attribute is named `publicPort` in VSD API.
                
        """
        self._public_port = value

    
    @property
    def external_id(self):
        """ Get external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        """ Set external_id value.

            Notes:
                External object ID. Used for integration with third party systems

                
                This attribute is named `externalID` in VSD API.
                
        """
        self._external_id = value

    
    @property
    def type(self):
        """ Get type value.

            Notes:
                Identifies the type of address mapping

                
        """
        return self._type

    @type.setter
    def type(self, value):
        """ Set type value.

            Notes:
                Identifies the type of address mapping

                
        """
        self._type = value

    

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from bambou import NURESTFetcher


class NUGatewayTemplatesFetcher(NURESTFetcher):
    """ Represents a NUGatewayTemplates fetcher

        Notes:
            This fetcher enables to fetch NUGatewayTemplate objects.

        See:
            bambou.NURESTFetcher
    """

    @classmethod
    def managed_class(cls):
        """ Return NUGatewayTemplate class that is managed.

            Returns:
                .NUGatewayTemplate: the managed class
        """

        from .. import NUGatewayTemplate
        return NUGatewayTemplate

    


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from .nuvsdsession import NUVSDSession
from .nume import NUMe

class SDKInfo (object):

    @classmethod
    def api_version(cls):
        """
            Returns the api version
        """
        return 5.0

    @classmethod
    def api_prefix(cls):
        """
            Returns the api prefix
        """
        return "nuage/api"

    @classmethod
    def product_accronym(cls):
        """
            Returns the product accronym
        """
        return "VSD"

    @classmethod
    def product_name(cls):
        """
            Returns the product name
        """
        return "VSD"

    @classmethod
    def class_prefix(cls):
        """
            Returns the api prefix
        """
        return "NU"

    @classmethod
    def name(cls):
        """
            Returns the sdk name
        """
        return "vspk"

    @classmethod
    def root_object_class(cls):
        """
            Returns the root object class
        """
        return NUMe

    @classmethod
    def session_class(cls):
        """
            Returns the session object class
        """
        return NUVSDSession


# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




from .fetchers import NUIKEGatewayConnectionsFetcher

from bambou import NURESTObject


class NUVirtualUplink(NURESTObject):
    """ Represents a VirtualUplink in the VSD

        Notes:
            Virtual Uplinks are entities that represent on an NSG the properties that are set for corresponding control uplink instances that are residing on the NSG RG Peer when tied together by a Shunt Link.
    """

    __rest_name__ = "virtualuplink"
    __resource_name__ = "virtualuplinks"

    
    ## Constants
    
    CONST_ROLE_UNKNOWN = "UNKNOWN"
    
    CONST_ROLE_NONE = "NONE"
    
    CONST_ROLE_SECONDARY = "SECONDARY"
    
    CONST_AUX_MODE_COLD = "COLD"
    
    CONST_AUX_MODE_NONE = "NONE"
    
    CONST_ROLE_TERTIARY = "TERTIARY"
    
    CONST_ROLE_PRIMARY = "PRIMARY"
    
    CONST_AUX_MODE_HOT = "HOT"
    
    

    def __init__(self, **kwargs):
        """ Initializes a VirtualUplink instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> virtualuplink = NUVirtualUplink(id=u'xxxx-xxx-xxx-xxx', name=u'VirtualUplink')
                >>> virtualuplink = NUVirtualUplink(data=my_dict)
        """

        super(NUVirtualUplink, self).__init__()

        # Read/Write Attributes
        
        self._peer_endpoint = None
        self._peer_gateway_id = None
        self._peer_gateway_name = None
        self._peer_gateway_system_id = None
        self._peer_port_id = None
        self._peer_uplink_id = None
        self._peer_vlanid = None
        self._shunt_endpoint = None
        self._shunt_port_id = None
        self._shunt_vlanid = None
        self._virtual_uplink_datapath_id = None
        self._enable_nat_probes = None
        self._underlay_id = None
        self._underlay_nat = None
        self._underlay_name = None
        self._underlay_routing = None
        self._role = None
        self._role_order = None
        self._traffic_through_ubr_only = None
        self._associated_egress_qo_s_policy_id = None
        self._associated_ingress_overlay_qo_s_policer_id = None
        self._associated_ingress_qo_s_policy_id = None
        self._associated_ingress_underlay_qo_s_policer_id = None
        self._associated_uplink_connection_id = None
        self._associated_vsc_profile_id = None
        self._aux_mode = None
        
        self.expose_attribute(local_name="peer_endpoint", remote_name="peerEndpoint", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_gateway_id", remote_name="peerGatewayID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_gateway_name", remote_name="peerGatewayName", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_gateway_system_id", remote_name="peerGatewaySystemID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_port_id", remote_name="peerPortID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_uplink_id", remote_name="peerUplinkID", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="peer_vlanid", remote_name="peerVLANID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="shunt_endpoint", remote_name="shuntEndpoint", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="shunt_port_id", remote_name="shuntPortID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="shunt_vlanid", remote_name="shuntVLANID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="virtual_uplink_datapath_id", remote_name="virtualUplinkDatapathID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="enable_nat_probes", remote_name="enableNATProbes", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="underlay_id", remote_name="underlayID", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="underlay_nat", remote_name="underlayNAT", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="underlay_name", remote_name="underlayName", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="underlay_routing", remote_name="underlayRouting", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PRIMARY', u'SECONDARY', u'TERTIARY', u'UNKNOWN'])
        self.expose_attribute(local_name="role_order", remote_name="roleOrder", attribute_type=int, is_required=False, is_unique=False)
        self.expose_attribute(local_name="traffic_through_ubr_only", remote_name="trafficThroughUBROnly", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_egress_qo_s_policy_id", remote_name="associatedEgressQoSPolicyID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_ingress_overlay_qo_s_policer_id", remote_name="associatedIngressOverlayQoSPolicerID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_ingress_qo_s_policy_id", remote_name="associatedIngressQoSPolicyID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_ingress_underlay_qo_s_policer_id", remote_name="associatedIngressUnderlayQoSPolicerID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_uplink_connection_id", remote_name="associatedUplinkConnectionID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="associated_vsc_profile_id", remote_name="associatedVSCProfileID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name="aux_mode", remote_name="auxMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'COLD', u'HOT', u'NONE'])
        

        # Fetchers
        
        
        self.ike_gateway_connections = NUIKEGatewayConnectionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
        

        self._compute_args(**kwargs)

    # Properties
    
    @property
    def peer_endpoint(self):
        """ Get peer_endpoint value.

            Notes:
                The physical port and VLAN endpoint hosting the peer control uplink that this virtual uplink mirrors. This is derived from the peer NSG of the Shunt Link in a redundant gateway group.

                
                This attribute is named `peerEndpoint` in VSD API.
                
        """
        return self._peer_endpoint

    @peer_endpoint.setter
    def peer_endpoint(self, value):
        """ Set peer_endpoint value.

            Notes:
                The physical port and VLAN endpoint hosting the peer control uplink that this virtual uplink mirrors. This is derived from the peer NSG of the Shunt Link in a redundant gateway group.

                
                This attribute is named `peerEndpoint` in VSD API.
                
        """
        self._peer_endpoint = value

    
    @property
    def peer_gateway_id(self):
        """ Get peer_gateway_id value.

            Notes:
                The UUID of the peer NSG in the redundant gateway group part of the Shunt Link.

                
                This attribute is named `peerGatewayID` in VSD API.
                
        """
        return self._peer_gateway_id

    @peer_gateway_id.setter
    def peer_gateway_id(self, value):
        """ Set peer_gateway_id value.

            Notes:
                The UUID of the peer NSG in the redundant gateway group part of the Shunt Link.

                
                This attribute is named `peerGatewayID` in VSD API.
                
        """
        self._peer_gateway_id = value

    
    @property
    def peer_gateway_name(self):
        """ Get peer_gateway_name value.

            Notes:
                The name of the peer NSG in the redundant gateway group part of the Shunt Link.

                
                This attribute is named `peerGatewayName` in VSD API.
                
        """
        return self._peer_gateway_name

    @peer_gateway_name.setter
    def peer_gateway_name(self, value):
        """ Set peer_gateway_name value.

            Notes:
                The name of the peer NSG in the redundant gateway group part of the Shunt Link.

                
                This attribute is named `peerGatewayName` in VSD API.
                
        """
        self._peer_gateway_name = value

    
    @property
    def peer_gateway_system_id(self):
        """ Get peer_gateway_system_id value.

            Notes:
                IP format of system generated identifier of the peer NSG.

                
                This attribute is named `peerGatewaySystemID` in VSD API.
                
        """
        return self._peer_gateway_system_id

    @peer_gateway_system_id.setter
    def peer_gateway_system_id(self, value):
        """ Set peer_gateway_system_id value.

            Notes:
                IP format of system generated identifier of the peer NSG.

                
                This attribute is named `peerGatewaySystemID` in VSD API.
                
        """
        self._peer_gateway_system_id = value

    
    @property
    def peer_port_id(self):
        """ Get peer_port_id value.

            Notes:
                The UUID of the port hosting the peer control uplink that this virtual uplink mirrors. This is derived from the peer NSG of the Shunt Link on a redundant gateway group.

                
                This attribute is named `peerPortID` in VSD API.
                
        """
        return self._peer_port_id

    @peer_port_id.setter
    def peer_port_id(self, value):
        """ Set peer_port_id value.

            Notes:
                The UUID of the port hosting the peer control uplink that this virtual uplink mirrors. This is derived from the peer NSG of the Shunt Link on a redundant gateway group.

                
                This attribute is named `peerPortID` in VSD API.
                
        """
        self._peer_port_id = value

    
    @property
    def peer_uplink_id(self):
        """ Get peer_uplink_id value.

            Notes:
                ID that unqiuely identifies the uplink. This attribute represents the configuration on the remote uplink connection that this virtual uplink mirrors.

                
                This attribute is named `peerUplinkID` in VSD API.
                
        """
        return self._peer_uplink_id

    @peer_uplink_id.setter
    def peer_uplink_id(self, value):
        """ Set peer_uplink_id value.

            Notes:
                ID that unqiuely identifies the uplink. This attribute represents the configuration on the remote uplink connection that this virtual uplink mirrors.

                
                This attribute is named `peerUplinkID` in VSD API.
                
        """
        self._peer_uplink_id = value

    
    @property
    def peer_vlanid(self):
        """ Get peer_vlanid value.

            Notes:
                The UUID of the VLAN in the control uplink that this virtual uplink mirrors.This is derived from the peer NSG of the Shunt Link on a redundant gateway group.

                
                This attribute is named `peerVLANID` in VSD API.
                
        """
        return self._peer_vlanid

    @peer_vlanid.setter
    def peer_vlanid(self, value):
        """ Set peer_vlanid value.

            Notes:
                The UUID of the VLAN in the control uplink that this virtual uplink mirrors.This is derived from the peer NSG of the Shunt Link on a redundant gateway group.

                
                This attribute is named `peerVLANID` in VSD API.
                
        """
        self._peer_vlanid = value

    
    @property
    def shunt_endpoint(self):
        """ Get shunt_endpoint value.

            Notes:
                The physical port and VLAN endpoint hosting the shunt endpoint on this Gateway.

                
                This attribute is named `shuntEndpoint` in VSD API.
                
        """
        return self._shunt_endpoint

    @shunt_endpoint.setter
    def shunt_endpoint(self, value):
        """ Set shunt_endpoint value.

            Notes:
                The physical port and VLAN endpoint hosting the shunt endpoint on this Gateway.

                
                This attribute is named `shuntEndpoint` in VSD API.
                
        """
        self._shunt_endpoint = value

    
    @property
    def shunt_port_id(self):
        """ Get shunt_port_id value.

            Notes:
                The UUID of the shunt port on the NSG hosting the Virtual Uplink.

                
                This attribute is named `shuntPortID` in VSD API.
                
        """
        return self._shunt_port_id

    @shunt_port_id.setter
    def shunt_port_id(self, value):
        """ Set shunt_port_id value.

            Notes:
                The UUID of the shunt port on the NSG hosting the Virtual Uplink.

                
                This attribute is named `shuntPortID` in VSD API.
                
        """
        self._shunt_port_id = value

    
    @property
    def shunt_vlanid(self):
        """ Get shunt_vlanid value.

            Notes:
                The UUID of the shunt VLAN on the NSG hosting the Virtual Uplink.

                
                This attribute is named `shuntVLANID` in VSD API.
                
        """
        return self._shunt_vlanid

    @shunt_vlanid.setter
    def shunt_vlanid(self, value):
        """ Set shunt_vlanid value.

            Notes:
                The UUID of the shunt VLAN on the NSG hosting the Virtual Uplink.

                
                This attribute is named `shuntVLANID` in VSD API.
                
        """
        self._shunt_vlanid = value

    
    @property
    def virtual_uplink_datapath_id(self):
        """ Get virtual_uplink_datapath_id value.

            Notes:
                IP format of system generated identifier of an uplink on NSG.

                
                This attribute is named `virtualUplinkDatapathID` in VSD API.
                
        """
        return self._virtual_uplink_datapath_id

    @virtual_uplink_datapath_id.setter
    def virtual_uplink_datapath_id(self, value):
        """ Set virtual_uplink_datapath_id value.

            Notes:
                IP format of system generated identifier of an uplink on NSG.

                
                This attribute is named `virtualUplinkDatapathID` in VSD API.
                
        """
        self._virtual_uplink_datapath_id = value

    
    @property
    def enable_nat_probes(self):
        """ Get enable_nat_probes value.

            Notes:
                If enabled, probes will be sent to other NSGs and DTLS sessions for IPSEC and VXLAN will be set up to the VSCs. If disabled, no NAT probes are sent on that uplink and no DTLS sessions are set up to the VSCs.

                
                This attribute is named `enableNATProbes` in VSD API.
                
        """
        return self._enable_nat_probes

    @enable_nat_probes.setter
    def enable_nat_probes(self, value):
        """ Set enable_nat_probes value.

            Notes:
                If enabled, probes will be sent to other NSGs and DTLS sessions for IPSEC and VXLAN will be set up to the VSCs. If disabled, no NAT probes are sent on that uplink and no DTLS sessions are set up to the VSCs.

                
                This attribute is named `enableNATProbes` in VSD API.
                
        """
        self._enable_nat_probes = value

    
    @property
    def underlay_id(self):
        """ Get underlay_id value.

            Notes:
                Underlay Identifier of underlay associated with the uplink mirrored by this Virtual Uplink.

                
                This attribute is named `underlayID` in VSD API.
                
        """
        return self._underlay_id

    @underlay_id.setter
    def underlay_id(self, value):
        """ Set underlay_id value.

            Notes:
                Underlay Identifier of underlay associated with the uplink mirrored by this Virtual Uplink.

                
                This attribute is named `underlayID` in VSD API.
                
        """
        self._underlay_id = value

    
    @property
    def underlay_nat(self):
        """ Get underlay_nat value.

            Notes:
                Indicates whether PAT is enabled on the underlay for this uplink connection. Inherits the PATEnabled attribute from remote uplink connection.

                
                This attribute is named `underlayNAT` in VSD API.
                
        """
        return self._underlay_nat

    @underlay_nat.setter
    def underlay_nat(self, value):
        """ Set underlay_nat value.

            Notes:
                Indicates whether PAT is enabled on the underlay for this uplink connection. Inherits the PATEnabled attribute from remote uplink connection.

                
                This attribute is named `underlayNAT` in VSD API.
                
        """
        self._underlay_nat = value

    
    @property
    def underlay_name(self):
        """ Get underlay_name value.

            Notes:
                Name of the underlay associated with the uplink mirrored by this Virtual Uplink.

                
                This attribute is named `underlayName` in VSD API.
                
        """
        return self._underlay_name

    @underlay_name.setter
    def underlay_name(self, value):
        """ Set underlay_name value.

            Notes:
                Name of the underlay associated with the uplink mirrored by this Virtual Uplink.

                
                This attribute is named `underlayName` in VSD API.
                
        """
        self._underlay_name = value

    
    @property
    def underlay_routing(self):
        """ Get underlay_routing value.

            Notes:
                Indicates whether route to underlay is enabled on the uplink connection that this Virtual uplink mirrors.

                
                This attribute is named `underlayRouting` in VSD API.
                
        """
        return self._underlay_routing

    @underlay_routing.setter
    def underlay_routing(self, value):
        """ Set underlay_routing value.

            Notes:
                Indicates whether route to underlay is enabled on the uplink connection that this Virtual uplink mirrors.

                
                This attribute is named `underlayRouting` in VSD API.
                
        """
        self._underlay_routing = value

    
    @property
    def role(self):
        """ Get role value.

            Notes:
                To allow prioritisation of traffic, the NSG network ports must be configured with an uplink type or tag value which will be used in the identification of packets being forwarded.  That identification is at the base of the selection of which network port will serve in sending packets to the outside world.  The default value is PRIMARY. Possible values are PRIMARY, SECONDARY, TERTIARY, UNKNOWN, This attribute represents the configuration on the remote uplink connection that this virtual uplink mirrors.

                
        """
        return self._role

    @role.setter
    def role(self, value):
        """ Set role value.

            Notes:
                To allow prioritisation of traffic, the NSG network ports must be configured with an uplink type or tag value which will be used in the identification of packets being forwarded.  That identification is at the base of the selection of which network port will serve in sending packets to the outside world.  The default value is PRIMARY. Possible values are PRIMARY, SECONDARY, TERTIARY, UNKNOWN, This attribute represents the configuration on the remote uplink connection that this virtual uplink mirrors.

                
        """
        self._role = value

    
    @property
    def role_order(self):
        """ Get role_order value.

            Notes:
                Determines the order in which uplinks are configured on NSG. It also determines the priority for an Uplink for management traffic. This value will be auto-generated based on the order of creation of Virtual Uplink.

                
                This attribute is named `roleOrder` in VSD API.
                
        """
        return self._role_order

    @role_order.setter
    def role_order(self, value):
        """ Set role_order value.

            Notes:
                Determines the order in which uplinks are configured on NSG. It also determines the priority for an Uplink for management traffic. This value will be auto-generated based on the order of creation of Virtual Uplink.

                
                This attribute is named `roleOrder` in VSD API.
                
        """
        self._role_order = value

    
    @property
    def traffic_through_ubr_only(self):
        """ Get traffic_through_ubr_only value.

            Notes:
                If enabled, cuts down the number of probes to just the number of provisioned UBRs. This attribute represents "             + "the configuration on the remote uplink connection that this virtual uplink mirrors.

                
                This attribute is named `trafficThroughUBROnly` in VSD API.
                
        """
        return self._traffic_through_ubr_only

    @traffic_through_ubr_only.setter
    def traffic_through_ubr_only(self, value):
        """ Set traffic_through_ubr_only value.

            Notes:
                If enabled, cuts down the number of probes to just the number of provisioned UBRs. This attribute represents "             + "the configuration on the remote uplink connection that this virtual uplink mirrors.

                
                This attribute is named `trafficThroughUBROnly` in VSD API.
                
        """
        self._traffic_through_ubr_only = value

    
    @property
    def associated_egress_qo_s_policy_id(self):
        """ Get associated_egress_qo_s_policy_id value.

            Notes:
                ID of the Egress QoS Policy associated with remote VlLAN.

                
                This attribute is named `associatedEgressQoSPolicyID` in VSD API.
                
        """
        return self._associated_egress_qo_s_policy_id

    @associated_egress_qo_s_policy_id.setter
    def associated_egress_qo_s_policy_id(self, value):
        """ Set associated_egress_qo_s_policy_id value.

            Notes:
                ID of the Egress QoS Policy associated with remote VlLAN.

                
                This attribute is named `associatedEgressQoSPolicyID` in VSD API.
                
        """
        self._associated_egress_qo_s_policy_id = value

    
    @property
    def associated_ingress_overlay_qo_s_policer_id(self):
        """ Get associated_ingress_overlay_qo_s_policer_id value.

            Notes:
                ID of the Ingress Overlay QoS Policer associated with the remote VlLAN.

                
                This attribute is named `associatedIngressOverlayQoSPolicerID` in VSD API.
                
        """
        return self._associated_ingress_overlay_qo_s_policer_id

    @associated_ingress_overlay_qo_s_policer_id.setter
    def associated_ingress_overlay_qo_s_policer_id(self, value):
        """ Set associated_ingress_overlay_qo_s_policer_id value.

            Notes:
                ID of the Ingress Overlay QoS Policer associated with the remote VlLAN.

                
                This attribute is named `associatedIngressOverlayQoSPolicerID` in VSD API.
                
        """
        self._associated_ingress_overlay_qo_s_policer_id = value

    
    @property
    def associated_ingress_qo_s_policy_id(self):
        """ Get associated_ingress_qo_s_policy_id value.

            Notes:
                ID of the Ingress QoS Policy / Tunnel Shaper associated with the remote VLAN.

                
                This attribute is named `associatedIngressQoSPolicyID` in VSD API.
                
        """
        return self._associated_ingress_qo_s_policy_id

    @associated_ingress_qo_s_policy_id.setter
    def associated_ingress_qo_s_policy_id(self, value):
        """ Set associated_ingress_qo_s_policy_id value.

            Notes:
                ID of the Ingress QoS Policy / Tunnel Shaper associated with the remote VLAN.

                
                This attribute is named `associatedIngressQoSPolicyID` in VSD API.
                
        """
        self._associated_ingress_qo_s_policy_id = value

    
    @property
    def associated_ingress_underlay_qo_s_policer_id(self):
        """ Get associated_ingress_underlay_qo_s_policer_id value.

            Notes:
                ID of the Ingress Underlay QoS Policer associated with the remote VLAN.

                
                This attribute is named `associatedIngressUnderlayQoSPolicerID` in VSD API.
                
        """
        return self._associated_ingress_underlay_qo_s_policer_id

    @associated_ingress_underlay_qo_s_policer_id.setter
    def associated_ingress_underlay_qo_s_policer_id(self, value):
        """ Set associated_ingress_underlay_qo_s_policer_id value.

            Notes:
                ID of the Ingress Underlay QoS Policer associated with the remote VLAN.

                
                This attribute is named `associatedIngressUnderlayQoSPolicerID` in VSD API.
                
        """
        self._associated_ingress_underlay_qo_s_policer_id = value

    
    @property
    def associated_uplink_connection_id(self):
        """ Get associated_uplink_connection_id value.

            Notes:
                UUID of the uplink connection from the peer NSG that this virtual uplink mirrors.

                
                This attribute is named `associatedUplinkConnectionID` in VSD API.
                
        """
        return self._associated_uplink_connection_id

    @associated_uplink_connection_id.setter
    def associated_uplink_connection_id(self, value):
        """ Set associated_uplink_connection_id value.

            Notes:
                UUID of the uplink connection from the peer NSG that this virtual uplink mirrors.

                
                This attribute is named `associatedUplinkConnectionID` in VSD API.
                
        """
        self._associated_uplink_connection_id = value

    
    @property
    def associated_vsc_profile_id(self):
        """ Get associated_vsc_profile_id value.

            Notes:
                The associated VSC profile of remote control uplink.

                
                This attribute is named `associatedVSCProfileID` in VSD API.
                
        """
        return self._associated_vsc_profile_id

    @associated_vsc_profile_id.setter
    def associated_vsc_profile_id(self, value):
        """ Set associated_vsc_profile_id value.

            Notes:
                The associated VSC profile of remote control uplink.

                
                This attribute is named `associatedVSCProfileID` in VSD API.
                
        """
        self._associated_vsc_profile_id = value

    
    @property
    def aux_mode(self):
        """ Get aux_mode value.

            Notes:
                Type of redundancy offered by the Uplink that is mirrored by this Virtual uplink when marked as auxiliary.

                
                This attribute is named `auxMode` in VSD API.
                
        """
        return self._aux_mode

    @aux_mode.setter
    def aux_mode(self, value):
        """ Set aux_mode value.

            Notes:
                Type of redundancy offered by the Uplink that is mirrored by this Virtual uplink when marked as auxiliary.

                
                This attribute is named `auxMode` in VSD API.
                
        """
        self._aux_mode = value

    

    